# CHANGELOG

## developing

- New
  - Importing Emoji Sequence data and new `EmojiSequence` class

- Change:
  - Re-structure the project
  - Rename `EmojiData` class to `EmojiCharacter`
  - Many other changes

- Upgrade:
  - Update emoji data files to 12.0

## 0.1.2

- Date: 2019-01-10

- New
  - Sphinx documentations

## 0.1.1

- Date: 2019-01-02

- Fix bugs.
- Add Circle-CI config

## 0.1.0

- Date: 2018-12-20

First version.
